@@ -1,9 +1,7 @@
 package Types::SQL;
 
-use strictures;
-
-use version;
-$Types::SQL::VERSION = version->declare('v0.0.3');
+use strict;
+use warnings;
 
 use Type::Library
   -base,
@@ -15,36 +13,13 @@ use Types::Standard -types;
 use PerlX::Maybe;
 
 # RECOMMEND PREREQ: PerlX::Maybe::XS
+# RECOMMEND PREREQ: Ref::Util::XS
 # RECOMMEND PREREQ: Type::Tiny::XS
 
-=head1 NAME
+# ABSTRACT: a library of SQL types
 
-Types::SQL - A library of SQL types
+our $VERSION = 'v0.1.3';
 
-=head1 SYNOPSIS
-
-  use Types::SQL -types;
-
-  my $type = Varchar[16];
-
-=head1 DESCRIPTION
-
-This module provides a type library of SQL types.  These are
-L<Type::Tiny> objects that are augmented with a C<dbic_column_info>
-method that returns column information for use with
-L<DBIx::Class>.
-
-=for readme stop
-
-The following types are provided:
-
-=head2 C<Blob>
-
-  my $type = Blob;
-
-Returns a C<blob> data type.
-
-=cut
 
 our $Blob = _generate_type(
     name             => 'Blob',
@@ -58,13 +33,6 @@ our $Blob = _generate_type(
     },
 );
 
-=head2 C<Text>
-
-  my $type = Text;
-
-Returns a C<text> data type.
-
-=cut
 
 our $Text = _generate_type(
     name             => 'Text',
@@ -78,13 +46,6 @@ our $Text = _generate_type(
     },
 );
 
-=head2 C<Varchar>
-
-  my $type = Varchar[ $size ];
-
-Returns a C<varchar> data type, with an optional size parameter.
-
-=cut
 
 our $Varchar = _generate_type(
     name                 => 'Varchar',
@@ -101,13 +62,6 @@ our $Varchar = _generate_type(
     },
 );
 
-=head2 C<Char>
-
-  my $type = Char[ $size ];
-
-Returns a C<char> data type, with an optional size parameter.
-
-=cut
 
 our $Char = _generate_type(
     name                 => 'Char',
@@ -124,13 +78,6 @@ our $Char = _generate_type(
     },
 );
 
-=head2 C<Integer>
-
-  my $type = Integer[ $precision ];
-
-Returns a C<integer> data type, with an optional precision parameter.
-
-=cut
 
 our $Integer = _generate_type(
     name                 => 'Integer',
@@ -146,13 +93,6 @@ our $Integer = _generate_type(
     },
 );
 
-=head2 C<Serial>
-
-  my $type = Serial[ $precision ];
-
-Returns a C<serial> data type, with an optional precision parameter.
-
-=cut
 
 our $Serial = _generate_type(
     name                 => 'Serial',
@@ -169,15 +109,6 @@ our $Serial = _generate_type(
     },
 );
 
-=head2 C<Numeric>
-
-  my $type = Numeric[ $precision, $scale ];
-
-Returns a C<integer> data type, with optional precision and scale parameters.
-
-If C<$scale> is omitted, then it is assumed to be C<0>.
-
-=cut
 
 our $Numeric = _generate_type(
     name                 => 'Numeric',
@@ -235,9 +166,89 @@ sub _generate_type {
     return $type;
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Types::SQL - a library of SQL types
+
+=head1 VERSION
+
+version v0.1.3
+
+=head1 SYNOPSIS
+
+  use Types::SQL -types;
+
+  my $type = Varchar[16];
+
+=head1 DESCRIPTION
+
+This module provides a type library of SQL types.  These are
+L<Type::Tiny> objects that are augmented with a C<dbic_column_info>
+method that returns column information for use with
+L<DBIx::Class>.
+
+=for readme stop
+
+=head1 TYPES
+
+The following types are provided:
+
+=head2 C<Blob>
+
+  my $type = Blob;
+
+Returns a C<blob> data type.
+
+=head2 C<Text>
+
+  my $type = Text;
+
+Returns a C<text> data type.
+
+=head2 C<Varchar>
+
+  my $type = Varchar[ $size ];
+
+Returns a C<varchar> data type, with an optional size parameter.
+
+=head2 C<Char>
+
+  my $type = Char[ $size ];
+
+Returns a C<char> data type, with an optional size parameter.
+
+=head2 C<Integer>
+
+  my $type = Integer[ $precision ];
+
+Returns a C<integer> data type, with an optional precision parameter.
+
+=head2 C<Serial>
+
+  my $type = Serial[ $precision ];
+
+Returns a C<serial> data type, with an optional precision parameter.
+
+=head2 C<Numeric>
+
+  my $type = Numeric[ $precision, $scale ];
+
+Returns a C<integer> data type, with optional precision and scale parameters.
+
+If C<$scale> is omitted, then it is assumed to be C<0>.
+
 =head1 CUSTOM TYPES
 
-Any type that has these types as a parent can have xolumn information
+Any type that has these types as a parent can have column information
 extracted using L<Types::SQL::Util>.
 
 Alternatively, you can specify a custom C<dbic_column_info> method in
@@ -270,54 +281,30 @@ L<Types::SQL::Util>, which provides a utility function for translating
 these types and other types from L<Types::Standard> into column
 information for L<DBIx::Class::ResultSource>.
 
+=head1 SOURCE
+
+The development version is on github at L<https://github.com/robrwo/Types-SQL>
+and may be cloned from L<git://github.com/robrwo/Types-SQL.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/robrwo/Types-SQL/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Robert Rothenberg, C<rrwo@cpan.org>
+Robert Rothenberg <rrwo@cpan.org>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 Robert Rothenberg.
+This software is Copyright (c) 2017 by Robert Rothenberg.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+This is free software, licensed under:
 
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-=for readme stop
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-=for readme continue
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-1;
